#
# spec file for package powerstat
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           powerstat
Version:        0.04.03
Release:        1.2
Summary:        Laptop power measuring tool
License:        GPL-2.0-only
URL:            https://github.com/ColinIanKing/powerstat
Source:         https://github.com/ColinIanKing/powerstat/archive/refs/tags/V%{version}.tar.gz

%description
Powerstat measures the power consumption of a mobile PC that has a battery
power source. The output is like vmstat but also shows power consumption
statistics. At the end of a run, powerstat will calculate the average,
standard deviation and min/max of the gathered data.

%package bash-completion
Summary:        Bash Completion for %{name}
BuildRequires:  bash-completion
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (powerstat and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%autosetup

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install

%files
%license COPYING
%doc README.md
%{_bindir}/powerstat
%{_mandir}/man8/powerstat.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Mon Mar 11 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 0.04.03:
  * Re-use last ujoules setting if current value is invalid
  * Ignore power readings that are zero
  * Minor copyright updates and optimization flag setting changes
* Thu Jun  8 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.03.03:
  * Don't fail if process netlink listen fails
  * Remove powercap debug
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.03.02:
  * Don't account for duplicated RAPL domains, make Watts field
    total of all RAPL domains
  * Makefile: bump minor version
  * Fix spelling mistake "informatiom" -> "information"
  * Makefile: use xz compression for dist tarball
  * Ignore duplicated power readings from RAPL mmio
  * Remove unused variable total_freq
  * Add min/max CPU frequencies, calculate CPU freq using
    geometric mean
  * Remove i915 power measurements
  * Add extra errno error information and check for access issues
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.02.28:
  * Add hint on how to use powerstat if -R option fails to find RAPL
  * Widen range of power_domains and thermal_zones, make them signed integers
  * powerstat: sanity check readdir name
  * Update copyright year
  * Clean up some whitespaces
  * powerstat: add notes on deprecated i915 power interface
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.02.27:
  * added README
  * snapcraft: update to core20
  * Return uint32_t from proc_info_hash
  * snap: add supported build architectures
  * Fix whitespace in strlcpy
* Mon Jun 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.26
  * Clean up some Coverity static analysis pedantic warnings
  * Use strlcpy instead of strncpy for safe string handling
  * Fix recv error when resources are low
* Mon Mar  1 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.25
  * Remove deprecated siginterrupt call, replace with SA_RESTART
    flag.
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0..02.24
  * no changelog available
* Sat May 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.23
  * Makefile: respect standard prefix= variable (LP: #1877744)
  * zero the ws struct to clear static analysis warnings
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.22
  * Add bash command completion script
* Mon Jan 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.21
  * No functional changes
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.20
  * No functional changes
* Sun Jul  7 2019 Martin Hauke <mardnh@gmx.de>
- update to version 0.02.18
  * Update copyright year
  * Make struct cpu_info pack more efficiently
* Mon Jul 23 2018 mardnh@gmx.de
- update to version 0.02.18
  * Makefile: bump version
  * Rename snapcraft directory to snap, add .travis.yml file to dist rule
  * Compute Geometric Mean without overflow with large sets of data
  * Add travis yaml file
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 0.02.17
  * Makefile: bump version
  * voidify returns from log_printf call
  * Make indices arrays const
  * Make cpu_freq_scale const
  * Add hint on how to run if not in "discharge" mode
  * Add adjustable C-state column width for C-state name column
  * snapcraft: make confinement strict
  * snapcraft: add plugs
* Sat May 19 2018 mardnh@gmx.de
- update to version 0.02.16
  * Makefile: bump version
  * debian/copyright: use secure https url
  * debian/control: remove empty last line
  * update debian/compat to 11
  * Fix range of CPU frequencies histogram. Scale by 1000 and not 1e9
* Wed Jan 31 2018 mardnh@gmx.de
- update to version 0.02.15
  * Makefile: bump version
  * Fix spelling mistake in comment
  * Update copyright year
  * Add GNU format attribute to log_printf
* Wed Nov  1 2017 mardnh@gmx.de
- update to version 0.02.14
  * Makefile: bump version
  * Add geometic mean to statistics
* Fri Oct 20 2017 mardnh@gmx.de
- update to version 0.02.13
  * Makefile: bump version
  * Increase temp buf from 16 to 32 bytes, cleans up gcc warning
  * Add more scanf sanity checking
  * debian/control: update Standards-version to 4.1.1
  * voidify function returns
  * use sizeof an object rather than the objects type
  * Don't use sentinel for end of signals[], use array size instead
  * include <sys/uio.h> for writev
  * powerstat: break wide macro over 2 lines
* Wed Jun 21 2017 mardnh@gmx.de
- update to version 0.02.12
  * Makefile: bump version
  * Makefile: add snapcraft files to dist rule
  * Fix incorrect GPU stats when sample rate is not 1 second (LP: #1699134)
  * snapcraft: add default type and grade keys
  * snapcraft: Makefile: remove icon hack
  * reduce the scope of the variable 'buf'
  * snapcraft.yaml: remove bogos unnecessary libs
  * Add snapcraft files
  * update copyright year
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.02.11
  * Makefile: bump version
  * Makefile: add mascot to dist rule
  * Remove two blank lines
  * Allow float compares a little slop
  * Makefile: add PEDANTIC flags
  * Add powerstat mascot
* Sat Jul 30 2016 mardnh@gmx.de
- update to version 0.02.10
  * Makefile: bump version
  * debian/control: update Standards-Version to 3.9.8
- update to version 0.02.09
  * Makefile: bump version
  * Do not overflow power domain and thermal zone buffers (LP: #1551297)
  * Tag RAPL stats as valid so stats show up in avg, std.dev. (LP: #1551287)
- update to version 0.02.08
  * Makefile: bump version
  * Move N/A message for GPU power right one char
  * Add some more per function comments
  * constify a few more func args
  * Make all non-main functions static
  * Minor fix up on GPU Watts field
  * Add GPU average stats
  * Clean up column formatting
  * add -g GPU stats
  * Update and correct copyright years
* Thu Feb 18 2016 mardnh@gmx.de
- update to version 0.02.07
  * Makefile: bump version
  * Manual: re-work some parts of the manual
  * Manual: add missong comma in SEE ALSO list
  * Move structure links to head of structures
  * Use a more efficient hashing function
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
